CustomAlertBox class

Constructors

CustomAlertBox()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

showCustomAlertBox({Color firstButtonColor = Colors.white, Color secondButtonColor = Colors.white, Color firstButtonTextColor = Colors.black, Color secondButtonTextColor = Colors.black, Color buttonShadowColor = Colors.black, bool barrierDismissible = true, required BuildContext context, required Widget headingWidget, required Widget descWidget, String firstButtonName = "Okay", String secondButtonName = "cancel", required dynamic firstButtonClick(), required dynamic secondButtonClick()}) Future